/*
 * i3dlib - image manipulation library
 *
 * Copyright (C) 2000-2006   Centre for Biomedical Image Analysis (CBIA)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * object.cc
 *
 * Class representing an object used in the region-based models
 *
 * Martin Maka (xmaska@fi.muni.cz) 2006 - 2011
 */

#include "object.h"

namespace i3d
{
	namespace fls
	{
		/////////////////////////////////////////////////////////////////
		//                                                             //
		//                        Class Object                         //
		//                                                             //
		/////////////////////////////////////////////////////////////////

		/**********************************************************************/

		void Object::Synchronize()
		{ 
			Type::Prec tmp = m_avg; 
			m_avg = (m_num == 0 ? Type::Prec(0) : m_intensity_sum / m_num);
			m_variance = (m_num == 0 ? Type::Prec(0) : m_sqr_intensity_sum / m_num - m_avg * m_avg);

			Type::Prec tmp2 = m_last_diff; 
			m_last_diff = Abs(m_avg - tmp); 
			m_diff_sum += Abs(m_last_diff - tmp2);
		}

		/**********************************************************************/

	} // namespace fls

} // namespace i3d

