/*
 * i3dlib - image manipulation library
 *
 * Copyright (C) 2000-2006   Centre for Biomedical Image Analysis (CBIA)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * object_list.cc
 *
 * Class representing a list of objects used in the region-based models
 *
 * Martin Maka (xmaska@fi.muni.cz) 2006 - 2011
 */

#include <iostream>
#include "object_list.h"

namespace i3d
{
	namespace fls
	{
		/////////////////////////////////////////////////////////////////
		//                                                             //
		//                      Class ObjectList                       //
		//                                                             //
		/////////////////////////////////////////////////////////////////

		/**********************************************************************/

		void ObjectList::Synchronize() 
		{ 
			std::map<Type::LabVoxel, Object>::iterator iter = m_list.begin(), last = m_list.end();

			while (iter != last)
			{
				iter -> second.Synchronize();
				++iter;
			}
		}

		/**********************************************************************/

		Type::Prec ObjectList::FlushDiff() 
		{ 
			Type::Prec sum = Type::Prec(0);
			std::map<Type::LabVoxel, Object>::iterator iter = m_list.begin(), last = m_list.end();

			while (iter != last)
			{
				sum += iter -> second.FlushDiff();
				++iter;
			}

			return sum;
		}

		/**********************************************************************/

		void ObjectList::Info() const 
		{ 
			std::map<Type::LabVoxel, Object>::const_iterator iter = m_list.begin(), last = m_list.end();
			std::cout.precision(15);

			while (iter != last)
			{
				std::cout << "Object " << iter -> first 
					      << ": size = " << iter -> second.Size() 
						  << ", avg = " << iter -> second.AvgIntensity() 
						  << ", var = " << iter -> second.Variance()
						  << std::endl;
				++iter;
			}
		}

		/**********************************************************************/

	} // namespace fls

} // namespace i3d

